==> dyte_client-0.2.1.tar.gz: android/src/main/java/com/dyteflutter/DyteMeetingView.java <==
package com.dyteflutter;


import android.app.Activity;
import android.content.Context;
import android.graphics.Color;
import android.util.Log;
import android.view.View;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import io.flutter.plugin.platform.PlatformView;
import java.util.Map;
import com.dyteclientmobile.DyteMeeting;
import com.dyteclientmobile.MeetingConfig;

class DyteMeetingView implements PlatformView {
    @NonNull private final View meetingView;

    DyteMeetingView(@NonNull Activity activity, int id, @Nullable Map<String, Object> creationParams) {

        String roomName = (String) creationParams.get("roomName");
        String authToken = (String) creationParams.get("authToken");
        Integer width = (Integer) creationParams.get("width");
        Integer height = (Integer) creationParams.get("height");
        String apiBase = (String) creationParams.get("apiBase");
        String orgId = (String) creationParams.get("orgId");
        Boolean autoTune = (Boolean) creationParams.get("autoTune");
        Boolean showSetupScreen = (Boolean) creationParams.get("showSetupScreen");

        MeetingConfig config = new MeetingConfig();
        config.setRoomName(roomName)
                .setAuthToken(authToken)
                .setOrgId(orgId)
                .setApiBase(apiBase)
                .setAutoTuneEnabled(autoTune)
                .setShowSetupScreen(showSetupScreen);

        DyteMeeting.setup(config);
        meetingView = DyteMeeting.init(activity, width, height);
    }

    @NonNull
    @Override
    public View getView() {
        return meetingView;
    }

    @Override
    public void dispose() {}
}

==> dyte_client-0.6.1.tar.gz: android/src/main/java/com/dyteflutter/DyteMeetingView.java <==
package com.dyteflutter;


import android.app.Activity;
import android.content.Context;
import android.graphics.Color;
import android.util.Log;
import android.view.View;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import io.flutter.plugin.platform.PlatformView;
import java.util.Map;
import com.dyteclientmobile.DyteMeeting;
import com.dyteclientmobile.MeetingConfig;

class DyteMeetingView implements PlatformView {
    @NonNull private final View meetingView;

    DyteMeetingView(@NonNull Activity activity, int id, @Nullable Map<String, Object> creationParams) {

        String roomName = (String) creationParams.get("roomName");
        String authToken = (String) creationParams.get("authToken");
        Integer width = (Integer) creationParams.get("width");
        Integer height = (Integer) creationParams.get("height");
        String apiBase = (String) creationParams.get("apiBase");
        String orgId = (String) creationParams.get("orgId");
        Boolean autoTune = (Boolean) creationParams.get("autoTune");
        Boolean showSetupScreen = (Boolean) creationParams.get("showSetupScreen");
        String uiConfig = (String) creationParams.get("uiConfig");
        MeetingConfig config = new MeetingConfig();
        config.setRoomName(roomName)
                .setAuthToken(authToken)
                .setOrgId(orgId)
                .setApiBase(apiBase)
                .setAutoTuneEnabled(autoTune)
                .setShowSetupScreen(showSetupScreen)
                .setUIconfig(uiConfig);

        DyteMeeting.setup(config);
        meetingView = DyteMeeting.init(activity, width, height);
    }

    @NonNull
    @Override
    public View getView() {
        return meetingView;
    }

    @Override
    public void dispose() {}
}
